# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0001_initial'),
        ('andablog', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='entry',
            name='tags',
            field=taggit.managers.TaggableManager(to='taggit.Tag', through='taggit.TaggedItem', blank=True, help_text='A comma-separated list of tags.', verbose_name='Tags'),
            preserve_default=True,
        ),
        migrations.AlterField(
            model_name='entry',
            name='author',
            field=models.ForeignKey(to=settings.AUTH_USER_MODEL, null=True, on_delete=models.CASCADE),
        ),
    ]



# Generated by Django 2.0.13 on 2019-03-15 15:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('andablog', '0006_auto_20170609_1759'),
    ]

    operations = [
        migrations.AddField(
            model_name='entry',
            name='content_markup_type',
            field=models.CharField(choices=[('', '--'), ('html', 'HTML'), ('plain', 'Plain'), ('markdown', 'Markdown'), ('restructuredtext', 'Restructured Text')], default='markdown', max_length=30),
        ),
        migrations.AddField(
            model_name='entry',
            name='preview_content_markup_type',
            field=models.CharField(choices=[('', '--'), ('html', 'HTML'), ('plain', 'Plain'), ('markdown', 'Markdown'), ('restructuredtext', 'Restructured Text')], default='markdown', max_length=30),
        ),
        migrations.AlterField(
            model_name='entry',
            name='_content_rendered',
            field=models.TextField(editable=False),
        ),
        migrations.AlterField(
            model_name='entry',
            name='_preview_content_rendered',
            field=models.TextField(editable=False),
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.11.2 on 2017-06-09 17:59
from __future__ import unicode_literals

from django.db import migrations, models
from markupfield.fields import MarkupField


class Migration(migrations.Migration):

    dependencies = [
        ('andablog', '0005_auto_20151017_1747'),
    ]

    operations = [
        migrations.AddField(
            model_name='entry',
            name='_preview_content_rendered',
            field=models.TextField(blank=True, editable=False),
        ),
        migrations.AddField(
            model_name='entry',
            name='preview_content',
            field=MarkupField(blank=True, default_markup_type='markdown'),
        ),
        migrations.AddField(
            model_name='entry',
            name='preview_image',
            field=models.ImageField(blank=True, upload_to='andablog/images'),
        ),
    ]
